@@ -622,6 +622,10 @@ def update_view_in_db(filepath, lineno):
 class ModulesCache(object):
     __cache = {}
 
+    @classmethod
+    def reset_cache(clazz):
+        ModulesCache.__cache.clear()
+
     @classmethod
     def _cache_dir(clazz):
         return Path(os.path.expanduser(f"~/.cache/wodoo"))
